@@ -7,18 +7,25 @@ from .decorators import enable
 class AfterResponseTest(TestCase):
 
     def test_execution(self):
-        self.executed = False
+        self.executed = 0
 
         @enable
         def func(val):
-            self.executed = val
+            self.executed += 1
 
-        self.assertFalse(self.executed)
+        self.assertEqual(self.executed, 0)
         self.client.get('/')
-        self.assertFalse(self.executed)
+        self.assertEqual(self.executed, 0)
 
         func.after_response(True)
 
-        self.assertFalse(self.executed)
+        self.assertEqual(self.executed, 0)
         self.client.get('/')
-        self.assertTrue(self.executed)
+        self.assertEqual(self.executed, 1)
+
+        func.after_response(True)
+        func.after_response(True)
+
+        self.assertEqual(self.executed, 1)
+        self.client.get('/')
+        self.assertEqual(self.executed, 3)
